import { PluginFunction, PluginValidateFn } from '@graphql-codegen/plugin-helpers';
import { NamingConvention } from '@graphql-codegen/visitor-plugin-common';
export interface TypeScriptDocumentNodesPluginConfig {
    /**
     * @name namingConvention
     * @type NamingConvention
     * @default change-case#pascalCase
     * @description Allow you to override the naming convention of the output.
     * You can either override all namings, or specify an object with specific custom naming convention per output.
     * The format of the converter must be a valid `module#method`.
     * You can also use "keep" to keep all GraphQL names as-is.
     * Additionally you can set `transformUnderscore` to `true` if you want to override the default behaviour,
     * which is to preserve underscores.
     *
     * @example Override All Names
     * ```yml
     * config:
     *   namingConvention: change-case#lowerCase
     * ```
     * @example Upper-case enum values
     * ```yml
     * config:
     *   namingConvention: change-case#pascalCase
     * ```
     * @example Keep
     * ```yml
     * config:
     *   namingConvention: keep
     * ```
     * @example Transform Underscores
     * ```yml
     * config:
     *   namingConvention: change-case#pascalCase
     *   transformUnderscore: true
     * ```
     */
    namingConvention?: NamingConvention;
    /**
     * @name namePrefix
     * @type string
     * @default ''
     * @description Adds prefix to the name
     *
     * @example
     * ```yml
     *  generates: src/api/user-service/queries.ts
     *  documents: src/api/user-service/queries.graphql
     *  plugins:
     *    - graphql-codegen-typescript-document-nodes
     *  config:
     *    namePrefix: 'gql'
     * ```
     */
    namePrefix?: string;
    /**
     * @name nameSuffix
     * @type string
     * @default ''
     * @description Adds suffix to the name
     *
     * @example
     * ```yml
     *  generates: src/api/user-service/queries.ts
     *  documents: src/api/user-service/queries.graphql
     *  plugins:
     *    - graphql-codegen-typescript-document-nodes
     *  config:
     *    nameSuffix: 'Query'
     * ```
     */
    nameSuffix?: string;
    /**
     * @name noGraphQLTag
     * @type boolean
     * @default false
     * @description Instead of adding gql tag with the GraphQL operation, it uses
     * the precompiled JSON representation (DocumentNode) of the operation.
     *
     * @example
     * ```yml
     * config:
     *   noGraphQLTag: true
     * ```
     */
    noGraphQLTag?: boolean;
    transformUnderscore?: boolean;
}
export declare const plugin: PluginFunction<TypeScriptDocumentNodesPluginConfig>;
export declare const validate: PluginValidateFn<any>;
